/******************************************************************************
 * Button polling and debouncing
 *
 * VERSIONS:
 *   2014-12-14  Arne Rossius
 *    * first version
 *
 ******************************************************************************/

#include <string.h>
#include <avr/io.h>

#include "buttons.h"
#include "tick.h"



volatile button_T buttons[BUTTON_GROUP1_QTY + BUTTON_GROUP2_QTY];



// poll buttons (called with 100 Hz)
static void buttons_tick(void) {
	uint8_t i, mask;
	button_T *btn = (button_T*)buttons;
	
	// poll first button group
	mask = 1<<BUTTON_GROUP1_FIRST;
	for (i = 0; i < BUTTON_GROUP1_QTY; i++) {
		if (BUTTON_GROUP1_PIN & mask) {
			// button not pressed
			if (btn[i].pressed) {
				btn[i].count = 0;
				btn[i].pressed = 0;
			}
		} else {
			// button pressed
			btn[i].pressed = 1;
			if (btn[i].count < 15) {
				if (btn[i].count == BUTTON_SHORT_PRESS) btn[i].short_press = 1;
				btn[i].count++;
			}
		}
		mask <<= 1;
	}
	
	// poll second button group
	mask = 1<<BUTTON_GROUP2_FIRST;
	for (i = BUTTON_GROUP1_QTY; i < BUTTON_GROUP1_QTY+BUTTON_GROUP2_QTY; i++) {
		if (BUTTON_GROUP2_PIN & mask) {
			// button not pressed
			if (btn[i].pressed) {
				btn[i].count = 0;
				btn[i].pressed = 0;
			}
		} else {
			// button pressed
			btn[i].pressed = 1;
			if (btn[i].count < 15) {
				if (btn[i].count == BUTTON_SHORT_PRESS) btn[i].short_press = 1;
				btn[i].count++;
			}
		}
		mask <<= 1;
	}
	
}



// initialize buttons
void buttons_init(void) {
	memset((void*)buttons, 0, sizeof(buttons));
	tick_add_function(buttons_tick);
}

// clear short_press buttons
void buttons_clear(void) {
	uint8_t i;
	for (i = 0; i < BUTTON_GROUP1_QTY + BUTTON_GROUP2_QTY; i++) {
		buttons[i].short_press = 0;
	}
}

// read one button
uint8_t buttons_read(uint8_t button) {
	if (buttons[button].short_press) {
		buttons[button].short_press = 0;
		return 1;
	} else {
		return 0;
	}
}
