#ifndef _LCD_H
#define _LCD_H

// LCD size
#define LCD_WIDTH 96
#define LCD_HEIGHT 60
#define LCD_PAGES ((LCD_HEIGHT + 7) / 8) /* pages = ceil(LCD_HEIGHT / 8) */

// LCD connection
#define LCD_DDR DDRC
#define LCD_PORT PORTC
#define LCD_RESET 3



// Charset
#include "charset/charset_cp437.h"
#define charset charset_cp437
#define CHAR_WIDTH CHARSET_CP437_WIDTH
#define CHAR_HEIGHT CHARSET_CP437_HEIGHT

#if defined(charset_cp437)
	// CP437 non-printable characters
	#define SMILEY_WHITE       0x01 // Smiley face, black on white
	#define SMILEY_BLACK       0x02 // Smiley face, white on black
	#define SUIT_HEARTS        0x03 // Playing card suit symbol "hearts"
	#define SUIT_DIAMONDS      0x04 // Playing card suit symbol "diamonds"
	#define SUIT_CLUBS         0x05 // Playing card suit symbol "clubs"
	#define SUIT_SPADES        0x06 // Playing card suit symbol "spades"
	#define CENTER_DOT         0x07 // Black centered round dot
	#define CENTER_DOT_INV     0x08 // White centered round dot on black
	#define CENTER_CIRCLE      0x09 // Black centered hollow circle
	#define CENTER_CIRCLE_INV  0x0A // White centered hollow circle on black
	#define GENDER_MALE        0x0B // Gender symbol "male"
	#define GENDER_FEMALE      0x0C // Gender symbol "female"
	#define MUSICAL_NOTE1      0x0D // Single musical note
	#define MUSICAL_NOTE2      0x0E // Double musical note
	#define SOLAR_SYMBOL       0x0F // Solar symbol
	#define TRIANGLE_RIGHT     0x10 // Right-pointing filled black triangle
	#define TRIANGLE_LEFT      0x11 // Left-pointing filled black triangle
	#define ARROW_UP_DOWN      0x12 // Up and down pointing arrow
	#define DOUBLE_EXCLAMATION 0x13 // Double exclamation mark
	#define PARAGRAPH_SIGN     0x14 // Paragraph sign (Pilcrow)
	#define SECTION_SIGN       0x15 // Section sign (double S)
	#define RECTANGLE          0x16 // Filled black rectangle
	#define ARROW_UP_DOWN_LINE 0x17 // Up and down arrow above horizontal line
	#define ARROW_UP           0x18 // Up-pointing arrow
	#define ARROW_DOWN         0x19 // Down-pointing arrrow
	#define ARROW_RIGHT        0x1A // Right-pointing arrow
	#define ARROW_LEFT         0x1B // Left-pointing arrow
	#define RIGHT_ANGLE        0x1C // Right angle (90 degrees) symbol
	#define ARROW_LEFT_RIGHT   0x1D // Left and right pointing arrow
	#define TRIANGLE_UP        0x1E // Up-pointing filled black triangle
	#define TRIANGLE_DOWN      0x1F // Down-pointing filled black triangle
	#define HOUSE_SYMBOL       0x7F // House
#endif



#include <stdint.h>

void lcd_init(void);
void lcd_contrast(uint8_t contrast);
void lcd_backlight(uint8_t brightness);
void lcd_clear(void);
void lcd_image(const uint8_t *image);
void lcd_image_P(const uint8_t *image);
void lcd_text(const char *text, uint8_t x, uint8_t y,
              uint8_t fb[LCD_PAGES][LCD_WIDTH]);
void lcd_text_P(const char *text, uint8_t x, uint8_t y,
                uint8_t fb[LCD_PAGES][LCD_WIDTH]);
void lcd_dec(uint16_t val, uint8_t digits, uint8_t x, uint8_t y,
             uint8_t fb[LCD_PAGES][LCD_WIDTH]);

#endif
