/******************************************************************************
 * Button polling and debouncing
 *
 * VERSIONS:
 *   2014-12-14  Arne Rossius
 *    * first version
 *
 ******************************************************************************/

#include <avr/io.h>

#include "uart.h"



// initialize UART
void uart_init(baud_T ubrr) {
	UBRR0 = ubrr;
	UCSR0B = 1<<TXEN0 | 1<<RXEN0;
}

// disable UART
void uart_disable(void) {
	UCSR0B = 0;
}

// check if data is available from UART
uint8_t uart_data_available(void) {
	return UCSR0A & 1<<RXC0;
}

// read char from UART
uint8_t uart_getc(void) {
	while (!(UCSR0A & 1<<RXC0));
	return UDR0;
}

// send char to UART
void uart_putc(uint8_t data) {
	while (!(UCSR0A & 1<<UDRE0));
	UDR0 = data;
}
